@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2015  B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2016  B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
@@ -22,8 +22,10 @@
 #ifndef _BATCTL_MAIN_H
 #define _BATCTL_MAIN_H
 
+#include <stdint.h>
+
 #ifndef SOURCE_VERSION
-#define SOURCE_VERSION "2015.1"
+#define SOURCE_VERSION "2016.0"
 #endif
 
 #define SOCKET_PATH_FMT "%s/batman_adv/%s/socket"
@@ -47,6 +49,9 @@
 #define __packed __attribute((packed))   /* linux kernel compat */
 #define BIT(nr)                 (1UL << (nr)) /* linux kernel compat */
 
+typedef uint8_t u8; /* linux kernel compat */
+typedef uint16_t u16; /* linux kernel compat */
+
 extern char module_ver_path[];
 
 #ifndef VLAN_VID_MASK
